==> 1.14.0.zip: hugo-typo/README.md <==
![banner](https://raw.githubusercontent.com/tomfran/typo/main/images/banner-light.webp)

# Typo, a Hugo theme.

Typo is a theme backed by simplicity, as you can see in the screenshots below. The goal was to have a website centered around content and nothing more.

[![wiki](https://img.shields.io/badge/doc-wiki-orange)](https://github.com/tomfran/typo/wiki)
[![hugo-typo](https://img.shields.io/badge/hugo_themes-@typo-red)](https://themes.gohugo.io/themes/typo/)
[![GitHub Release](https://img.shields.io/github/v/release/tomfran/typo)](https://github.com/tomfran/typo/releases/latest)
[![last-commit](https://img.shields.io/github/last-commit/tomfran/typo)](https://github.com/tomfran/typo/commits/)

**Homepage**

![1](https://raw.githubusercontent.com/tomfran/typo/main/images/1.webp)

**Article**

![2](https://raw.githubusercontent.com/tomfran/typo/main/images/2.webp)

![3](https://raw.githubusercontent.com/tomfran/typo/main/images/3.webp)

---

**Table of content**

- [1 Setup](#1-setup)
- [2 Features](#2-features)
- [3 References](#3-references)
- [4 Support](#4-support)
- [5 Typo Users](#5-typo-users)
- [6 Questions or Ideas?](#6-questions-or-ideas)

---

## 1 Setup

You can install Typo in various ways, the [setup wiki](https://github.com/tomfran/typo/wiki/Setup) page highlights how to do so.

## 2 Features

The theme has various features, such as header auto-numbering, auto dark mode, color palettes, and dark and light images. 
Have a look at the [wiki](https://github.com/tomfran/typo/wiki/Features) for a complete overview of the available ones.

## 3 References

The SVGs for social icons are taken from [Hugo PaperMod](https://github.com/adityatelange/hugo-PaperMod).

## 4 Support

If you use the theme or found it useful you can support me by leaving a star ⭐ to Typo's Github repository.

Contributions are always welcome, feel free to open issues and PRs with fixes or new features.

## 5 Typo Users

If you're using Typo for your website, feel free to add your website to [the list](https://github.com/tomfran/typo/blob/main/USERS.md) alongside what you do! 😊

## 6 Questions or Ideas? 

Use the [discussion tab](https://github.com/tomfran/typo/discussions) to share ideas/tips/questions about Typo or Hugo in general!

==> v1.15.0.zip: hugo-typo/README.md <==
![banner](https://raw.githubusercontent.com/tomfran/typo/main/images/banner-light.webp)

# Typo, a Hugo theme.

Typo is a theme backed by simplicity, as you can see in the screenshots below. The goal was to have a website centered around content and nothing more.

[![wiki](https://img.shields.io/badge/doc-wiki-orange)](https://tomfran.github.io/typo-wiki/)
[![hugo-typo](https://img.shields.io/badge/hugo_themes-@typo-red)](https://themes.gohugo.io/themes/typo/)
[![GitHub Release](https://img.shields.io/github/v/release/tomfran/typo)](https://github.com/tomfran/typo/releases/latest)
[![last-commit](https://img.shields.io/github/last-commit/tomfran/typo)](https://github.com/tomfran/typo/commits/)

**Homepage**

![1](https://raw.githubusercontent.com/tomfran/typo/main/images/1.webp)

**Article**

![2](https://raw.githubusercontent.com/tomfran/typo/main/images/2.webp)

![3](https://raw.githubusercontent.com/tomfran/typo/main/images/3.webp)

---

**Table of content**

- [1 Setup](#1-setup)
- [2 Features](#2-features)
- [3 References](#3-references)
- [4 Support](#4-support)
- [5 Typo Users](#5-typo-users)
- [6 Questions or ideas?](#6-questions-or-ideas)

---

## 1 Setup

You can install Typo in various ways, the [setup wiki](https://tomfran.github.io/typo-wiki/setup) page highlights how to do so.

## 2 Features

The theme has various features, such as header auto-numbering, auto dark mode, color palettes, and dark and light images. 
Have a look at the [wiki](https://tomfran.github.io/typo-wiki/features) for a complete overview of the available ones.

## 3 References

The SVGs for social icons are taken from [Simple Icons](https://github.com/simple-icons/simple-icons).
Every SVG present on the website is usable on the theme.

## 4 Support

If you use the theme or found it useful you can support me by leaving a star ⭐ to Typo's Github repository.

Contributions are always welcome, feel free to open issues and PRs with fixes or new features.

## 5 Typo Users

If you're using Typo for your website, feel free to add your website to [the list](https://github.com/tomfran/typo/blob/main/USERS.md) alongside what you do! 😊

## 6 Questions or ideas? 

Use the [discussion tab](https://github.com/tomfran/typo/discussions) to share ideas/tips/questions about Typo or Hugo in general!
